Class: SwaggyJenkinsClient::BranchImpl

Inherits:
ApiModelBase show all
Defined in:
lib/swaggy_jenkins/models/branch_impl.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BranchImpl

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::BranchImpl` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::BranchImpl`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'estimated_duration_in_millis')
    self.estimated_duration_in_millis = attributes[:'estimated_duration_in_millis']
  end

  if attributes.key?(:'full_display_name')
    self.full_display_name = attributes[:'full_display_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'parameters')
    if (value = attributes[:'parameters']).is_a?(Array)
      self.parameters = value
    end
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  end

  if attributes.key?(:'weather_score')
    self.weather_score = attributes[:'weather_score']
  end

  if attributes.key?(:'pull_request')
    self.pull_request = attributes[:'pull_request']
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end

  if attributes.key?(:'latest_run')
    self.latest_run = attributes[:'latest_run']
  end
end

Instance Attribute Details

#_classObject

Returns the value of attribute _class.



18
19
20
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 18

def _class
  @_class
end

Returns the value of attribute _links.



40
41
42
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 40

def _links
  @_links
end

#display_nameObject

Returns the value of attribute display_name.



20
21
22
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 20

def display_name
  @display_name
end

#estimated_duration_in_millisObject

Returns the value of attribute estimated_duration_in_millis.



22
23
24
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 22

def estimated_duration_in_millis
  @estimated_duration_in_millis
end

#full_display_nameObject

Returns the value of attribute full_display_name.



24
25
26
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 24

def full_display_name
  @full_display_name
end

#full_nameObject

Returns the value of attribute full_name.



26
27
28
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 26

def full_name
  @full_name
end

#latest_runObject

Returns the value of attribute latest_run.



42
43
44
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 42

def latest_run
  @latest_run
end

#nameObject

Returns the value of attribute name.



28
29
30
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 28

def name
  @name
end

#organizationObject

Returns the value of attribute organization.



30
31
32
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 30

def organization
  @organization
end

#parametersObject

Returns the value of attribute parameters.



32
33
34
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 32

def parameters
  @parameters
end

#permissionsObject

Returns the value of attribute permissions.



34
35
36
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 34

def permissions
  @permissions
end

#pull_requestObject

Returns the value of attribute pull_request.



38
39
40
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 38

def pull_request
  @pull_request
end

#weather_scoreObject

Returns the value of attribute weather_score.



36
37
38
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 36

def weather_score
  @weather_score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 45

def self.attribute_map
  {
    :'_class' => :'_class',
    :'display_name' => :'displayName',
    :'estimated_duration_in_millis' => :'estimatedDurationInMillis',
    :'full_display_name' => :'fullDisplayName',
    :'full_name' => :'fullName',
    :'name' => :'name',
    :'organization' => :'organization',
    :'parameters' => :'parameters',
    :'permissions' => :'permissions',
    :'weather_score' => :'weatherScore',
    :'pull_request' => :'pullRequest',
    :'_links' => :'_links',
    :'latest_run' => :'latestRun'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 74

def self.openapi_types
  {
    :'_class' => :'String',
    :'display_name' => :'String',
    :'estimated_duration_in_millis' => :'Integer',
    :'full_display_name' => :'String',
    :'full_name' => :'String',
    :'name' => :'String',
    :'organization' => :'String',
    :'parameters' => :'Array<StringParameterDefinition>',
    :'permissions' => :'BranchImplpermissions',
    :'weather_score' => :'Integer',
    :'pull_request' => :'String',
    :'_links' => :'BranchImpllinks',
    :'latest_run' => :'PipelineRunImpl'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _class == o._class &&
      display_name == o.display_name &&
      estimated_duration_in_millis == o.estimated_duration_in_millis &&
      full_display_name == o.full_display_name &&
      full_name == o.full_name &&
      name == o.name &&
      organization == o.organization &&
      parameters == o.parameters &&
      permissions == o.permissions &&
      weather_score == o.weather_score &&
      pull_request == o.pull_request &&
      _links == o._links &&
      latest_run == o.latest_run
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 212

def hash
  [_class, display_name, estimated_duration_in_millis, full_display_name, full_name, name, organization, parameters, permissions, weather_score, pull_request, _links, latest_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
# File 'lib/swaggy_jenkins/models/branch_impl.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end