Class: SwaggyJenkinsClient::FreeStyleBuild

Inherits:
ApiModelBase show all
Defined in:
lib/swaggy_jenkins/models/free_style_build.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FreeStyleBuild

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::FreeStyleBuild` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::FreeStyleBuild`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'building')
    self.building = attributes[:'building']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'estimated_duration')
    self.estimated_duration = attributes[:'estimated_duration']
  end

  if attributes.key?(:'executor')
    self.executor = attributes[:'executor']
  end

  if attributes.key?(:'full_display_name')
    self.full_display_name = attributes[:'full_display_name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'keep_log')
    self.keep_log = attributes[:'keep_log']
  end

  if attributes.key?(:'queue_id')
    self.queue_id = attributes[:'queue_id']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'built_on')
    self.built_on = attributes[:'built_on']
  end

  if attributes.key?(:'change_set')
    self.change_set = attributes[:'change_set']
  end
end

Instance Attribute Details

#_classObject

Returns the value of attribute _class.



18
19
20
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 18

def _class
  @_class
end

#actionsObject

Returns the value of attribute actions.



24
25
26
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 24

def actions
  @actions
end

#buildingObject

Returns the value of attribute building.



26
27
28
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 26

def building
  @building
end

#built_onObject

Returns the value of attribute built_on.



50
51
52
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 50

def built_on
  @built_on
end

#change_setObject

Returns the value of attribute change_set.



52
53
54
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 52

def change_set
  @change_set
end

#descriptionObject

Returns the value of attribute description.



28
29
30
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 28

def description
  @description
end

#display_nameObject

Returns the value of attribute display_name.



30
31
32
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 30

def display_name
  @display_name
end

#durationObject

Returns the value of attribute duration.



32
33
34
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 32

def duration
  @duration
end

#estimated_durationObject

Returns the value of attribute estimated_duration.



34
35
36
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 34

def estimated_duration
  @estimated_duration
end

#executorObject

Returns the value of attribute executor.



36
37
38
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 36

def executor
  @executor
end

#full_display_nameObject

Returns the value of attribute full_display_name.



38
39
40
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 38

def full_display_name
  @full_display_name
end

#idObject

Returns the value of attribute id.



40
41
42
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 40

def id
  @id
end

#keep_logObject

Returns the value of attribute keep_log.



42
43
44
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 42

def keep_log
  @keep_log
end

#numberObject

Returns the value of attribute number.



20
21
22
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 20

def number
  @number
end

#queue_idObject

Returns the value of attribute queue_id.



44
45
46
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 44

def queue_id
  @queue_id
end

#resultObject

Returns the value of attribute result.



46
47
48
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 46

def result
  @result
end

#timestampObject

Returns the value of attribute timestamp.



48
49
50
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 48

def timestamp
  @timestamp
end

#urlObject

Returns the value of attribute url.



22
23
24
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 22

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 55

def self.attribute_map
  {
    :'_class' => :'_class',
    :'number' => :'number',
    :'url' => :'url',
    :'actions' => :'actions',
    :'building' => :'building',
    :'description' => :'description',
    :'display_name' => :'displayName',
    :'duration' => :'duration',
    :'estimated_duration' => :'estimatedDuration',
    :'executor' => :'executor',
    :'full_display_name' => :'fullDisplayName',
    :'id' => :'id',
    :'keep_log' => :'keepLog',
    :'queue_id' => :'queueId',
    :'result' => :'result',
    :'timestamp' => :'timestamp',
    :'built_on' => :'builtOn',
    :'change_set' => :'changeSet'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 264

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 89

def self.openapi_types
  {
    :'_class' => :'String',
    :'number' => :'Integer',
    :'url' => :'String',
    :'actions' => :'Array<CauseAction>',
    :'building' => :'Boolean',
    :'description' => :'String',
    :'display_name' => :'String',
    :'duration' => :'Integer',
    :'estimated_duration' => :'Integer',
    :'executor' => :'String',
    :'full_display_name' => :'String',
    :'id' => :'String',
    :'keep_log' => :'Boolean',
    :'queue_id' => :'Integer',
    :'result' => :'String',
    :'timestamp' => :'Integer',
    :'built_on' => :'String',
    :'change_set' => :'EmptyChangeLogSet'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _class == o._class &&
      number == o.number &&
      url == o.url &&
      actions == o.actions &&
      building == o.building &&
      description == o.description &&
      display_name == o.display_name &&
      duration == o.duration &&
      estimated_duration == o.estimated_duration &&
      executor == o.executor &&
      full_display_name == o.full_display_name &&
      id == o.id &&
      keep_log == o.keep_log &&
      queue_id == o.queue_id &&
      result == o.result &&
      timestamp == o.timestamp &&
      built_on == o.built_on &&
      change_set == o.change_set
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 251

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



257
258
259
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 257

def hash
  [_class, number, url, actions, building, description, display_name, duration, estimated_duration, executor, full_display_name, id, keep_log, queue_id, result, timestamp, built_on, change_set].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
# File 'lib/swaggy_jenkins/models/free_style_build.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end