Class: SwaggyJenkinsClient::HudsonMasterComputer

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/swaggy_jenkins/models/hudson_master_computer.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ HudsonMasterComputer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::HudsonMasterComputer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::HudsonMasterComputer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'executors')
    if (value = attributes[:'executors']).is_a?(Array)
      self.executors = value
    end
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'icon_class_name')
    self.icon_class_name = attributes[:'icon_class_name']
  end

  if attributes.key?(:'idle')
    self.idle = attributes[:'idle']
  end

  if attributes.key?(:'jnlp_agent')
    self.jnlp_agent = attributes[:'jnlp_agent']
  end

  if attributes.key?(:'launch_supported')
    self.launch_supported = attributes[:'launch_supported']
  end

  if attributes.key?(:'load_statistics')
    self.load_statistics = attributes[:'load_statistics']
  end

  if attributes.key?(:'manual_launch_allowed')
    self.manual_launch_allowed = attributes[:'manual_launch_allowed']
  end

  if attributes.key?(:'monitor_data')
    self.monitor_data = attributes[:'monitor_data']
  end

  if attributes.key?(:'num_executors')
    self.num_executors = attributes[:'num_executors']
  end

  if attributes.key?(:'offline')
    self.offline = attributes[:'offline']
  end

  if attributes.key?(:'offline_cause')
    self.offline_cause = attributes[:'offline_cause']
  end

  if attributes.key?(:'offline_cause_reason')
    self.offline_cause_reason = attributes[:'offline_cause_reason']
  end

  if attributes.key?(:'temporarily_offline')
    self.temporarily_offline = attributes[:'temporarily_offline']
  end
end

Instance Attribute Details

#_classObject

Returns the value of attribute _class.



18
19
20
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 18

def _class
  @_class
end

#display_nameObject

Returns the value of attribute display_name.



20
21
22
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 20

def display_name
  @display_name
end

#executorsObject

Returns the value of attribute executors.



22
23
24
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 22

def executors
  @executors
end

#iconObject

Returns the value of attribute icon.



24
25
26
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 24

def icon
  @icon
end

#icon_class_nameObject

Returns the value of attribute icon_class_name.



26
27
28
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 26

def icon_class_name
  @icon_class_name
end

#idleObject

Returns the value of attribute idle.



28
29
30
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 28

def idle
  @idle
end

#jnlp_agentObject

Returns the value of attribute jnlp_agent.



30
31
32
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 30

def jnlp_agent
  @jnlp_agent
end

#launch_supportedObject

Returns the value of attribute launch_supported.



32
33
34
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 32

def launch_supported
  @launch_supported
end

#load_statisticsObject

Returns the value of attribute load_statistics.



34
35
36
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 34

def load_statistics
  @load_statistics
end

#manual_launch_allowedObject

Returns the value of attribute manual_launch_allowed.



36
37
38
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 36

def manual_launch_allowed
  @manual_launch_allowed
end

#monitor_dataObject

Returns the value of attribute monitor_data.



38
39
40
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 38

def monitor_data
  @monitor_data
end

#num_executorsObject

Returns the value of attribute num_executors.



40
41
42
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 40

def num_executors
  @num_executors
end

#offlineObject

Returns the value of attribute offline.



42
43
44
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 42

def offline
  @offline
end

#offline_causeObject

Returns the value of attribute offline_cause.



44
45
46
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 44

def offline_cause
  @offline_cause
end

#offline_cause_reasonObject

Returns the value of attribute offline_cause_reason.



46
47
48
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 46

def offline_cause_reason
  @offline_cause_reason
end

#temporarily_offlineObject

Returns the value of attribute temporarily_offline.



48
49
50
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 48

def temporarily_offline
  @temporarily_offline
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 51

def self.attribute_map
  {
    :'_class' => :'_class',
    :'display_name' => :'displayName',
    :'executors' => :'executors',
    :'icon' => :'icon',
    :'icon_class_name' => :'iconClassName',
    :'idle' => :'idle',
    :'jnlp_agent' => :'jnlpAgent',
    :'launch_supported' => :'launchSupported',
    :'load_statistics' => :'loadStatistics',
    :'manual_launch_allowed' => :'manualLaunchAllowed',
    :'monitor_data' => :'monitorData',
    :'num_executors' => :'numExecutors',
    :'offline' => :'offline',
    :'offline_cause' => :'offlineCause',
    :'offline_cause_reason' => :'offlineCauseReason',
    :'temporarily_offline' => :'temporarilyOffline'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 83

def self.openapi_types
  {
    :'_class' => :'String',
    :'display_name' => :'String',
    :'executors' => :'Array<HudsonMasterComputerexecutors>',
    :'icon' => :'String',
    :'icon_class_name' => :'String',
    :'idle' => :'Boolean',
    :'jnlp_agent' => :'Boolean',
    :'launch_supported' => :'Boolean',
    :'load_statistics' => :'Label1',
    :'manual_launch_allowed' => :'Boolean',
    :'monitor_data' => :'HudsonMasterComputermonitorData',
    :'num_executors' => :'Integer',
    :'offline' => :'Boolean',
    :'offline_cause' => :'String',
    :'offline_cause_reason' => :'String',
    :'temporarily_offline' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _class == o._class &&
      display_name == o.display_name &&
      executors == o.executors &&
      icon == o.icon &&
      icon_class_name == o.icon_class_name &&
      idle == o.idle &&
      jnlp_agent == o.jnlp_agent &&
      launch_supported == o.launch_supported &&
      load_statistics == o.load_statistics &&
      manual_launch_allowed == o.manual_launch_allowed &&
      monitor_data == o.monitor_data &&
      num_executors == o.num_executors &&
      offline == o.offline &&
      offline_cause == o.offline_cause &&
      offline_cause_reason == o.offline_cause_reason &&
      temporarily_offline == o.temporarily_offline
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 239

def hash
  [_class, display_name, executors, icon, icon_class_name, idle, jnlp_agent, launch_supported, load_statistics, manual_launch_allowed, monitor_data, num_executors, offline, offline_cause, offline_cause_reason, temporarily_offline].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
# File 'lib/swaggy_jenkins/models/hudson_master_computer.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end