Class: SwaggyJenkinsClient::MultibranchPipeline

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/swaggy_jenkins/models/multibranch_pipeline.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MultibranchPipeline

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::MultibranchPipeline` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::MultibranchPipeline`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'estimated_duration_in_millis')
    self.estimated_duration_in_millis = attributes[:'estimated_duration_in_millis']
  end

  if attributes.key?(:'latest_run')
    self.latest_run = attributes[:'latest_run']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'weather_score')
    self.weather_score = attributes[:'weather_score']
  end

  if attributes.key?(:'branch_names')
    if (value = attributes[:'branch_names']).is_a?(Array)
      self.branch_names = value
    end
  end

  if attributes.key?(:'number_of_failing_branches')
    self.number_of_failing_branches = attributes[:'number_of_failing_branches']
  end

  if attributes.key?(:'number_of_failing_pull_requests')
    self.number_of_failing_pull_requests = attributes[:'number_of_failing_pull_requests']
  end

  if attributes.key?(:'number_of_successful_branches')
    self.number_of_successful_branches = attributes[:'number_of_successful_branches']
  end

  if attributes.key?(:'number_of_successful_pull_requests')
    self.number_of_successful_pull_requests = attributes[:'number_of_successful_pull_requests']
  end

  if attributes.key?(:'total_number_of_branches')
    self.total_number_of_branches = attributes[:'total_number_of_branches']
  end

  if attributes.key?(:'total_number_of_pull_requests')
    self.total_number_of_pull_requests = attributes[:'total_number_of_pull_requests']
  end

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end
end

Instance Attribute Details

#_classObject

Returns the value of attribute _class.



44
45
46
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 44

def _class
  @_class
end

#branch_namesObject

Returns the value of attribute branch_names.



30
31
32
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 30

def branch_names
  @branch_names
end

#display_nameObject

Returns the value of attribute display_name.



18
19
20
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 18

def display_name
  @display_name
end

#estimated_duration_in_millisObject

Returns the value of attribute estimated_duration_in_millis.



20
21
22
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 20

def estimated_duration_in_millis
  @estimated_duration_in_millis
end

#latest_runObject

Returns the value of attribute latest_run.



22
23
24
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 22

def latest_run
  @latest_run
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 24

def name
  @name
end

#number_of_failing_branchesObject

Returns the value of attribute number_of_failing_branches.



32
33
34
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 32

def number_of_failing_branches
  @number_of_failing_branches
end

#number_of_failing_pull_requestsObject

Returns the value of attribute number_of_failing_pull_requests.



34
35
36
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 34

def number_of_failing_pull_requests
  @number_of_failing_pull_requests
end

#number_of_successful_branchesObject

Returns the value of attribute number_of_successful_branches.



36
37
38
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 36

def number_of_successful_branches
  @number_of_successful_branches
end

#number_of_successful_pull_requestsObject

Returns the value of attribute number_of_successful_pull_requests.



38
39
40
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 38

def number_of_successful_pull_requests
  @number_of_successful_pull_requests
end

#organizationObject

Returns the value of attribute organization.



26
27
28
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 26

def organization
  @organization
end

#total_number_of_branchesObject

Returns the value of attribute total_number_of_branches.



40
41
42
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 40

def total_number_of_branches
  @total_number_of_branches
end

#total_number_of_pull_requestsObject

Returns the value of attribute total_number_of_pull_requests.



42
43
44
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 42

def total_number_of_pull_requests
  @total_number_of_pull_requests
end

#weather_scoreObject

Returns the value of attribute weather_score.



28
29
30
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 28

def weather_score
  @weather_score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 47

def self.attribute_map
  {
    :'display_name' => :'displayName',
    :'estimated_duration_in_millis' => :'estimatedDurationInMillis',
    :'latest_run' => :'latestRun',
    :'name' => :'name',
    :'organization' => :'organization',
    :'weather_score' => :'weatherScore',
    :'branch_names' => :'branchNames',
    :'number_of_failing_branches' => :'numberOfFailingBranches',
    :'number_of_failing_pull_requests' => :'numberOfFailingPullRequests',
    :'number_of_successful_branches' => :'numberOfSuccessfulBranches',
    :'number_of_successful_pull_requests' => :'numberOfSuccessfulPullRequests',
    :'total_number_of_branches' => :'totalNumberOfBranches',
    :'total_number_of_pull_requests' => :'totalNumberOfPullRequests',
    :'_class' => :'_class'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 228

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 77

def self.openapi_types
  {
    :'display_name' => :'String',
    :'estimated_duration_in_millis' => :'Integer',
    :'latest_run' => :'String',
    :'name' => :'String',
    :'organization' => :'String',
    :'weather_score' => :'Integer',
    :'branch_names' => :'Array<String>',
    :'number_of_failing_branches' => :'Integer',
    :'number_of_failing_pull_requests' => :'Integer',
    :'number_of_successful_branches' => :'Integer',
    :'number_of_successful_pull_requests' => :'Integer',
    :'total_number_of_branches' => :'Integer',
    :'total_number_of_pull_requests' => :'Integer',
    :'_class' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_name == o.display_name &&
      estimated_duration_in_millis == o.estimated_duration_in_millis &&
      latest_run == o.latest_run &&
      name == o.name &&
      organization == o.organization &&
      weather_score == o.weather_score &&
      branch_names == o.branch_names &&
      number_of_failing_branches == o.number_of_failing_branches &&
      number_of_failing_pull_requests == o.number_of_failing_pull_requests &&
      number_of_successful_branches == o.number_of_successful_branches &&
      number_of_successful_pull_requests == o.number_of_successful_pull_requests &&
      total_number_of_branches == o.total_number_of_branches &&
      total_number_of_pull_requests == o.total_number_of_pull_requests &&
      _class == o._class
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


215
216
217
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 215

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



221
222
223
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 221

def hash
  [display_name, estimated_duration_in_millis, latest_run, name, organization, weather_score, branch_names, number_of_failing_branches, number_of_failing_pull_requests, number_of_successful_branches, number_of_successful_pull_requests, total_number_of_branches, total_number_of_pull_requests, _class].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 250

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
# File 'lib/swaggy_jenkins/models/multibranch_pipeline.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end