Class: SwaggyJenkinsClient::PipelineBranchesitemlatestRun

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PipelineBranchesitemlatestRun

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::PipelineBranchesitemlatestRun` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::PipelineBranchesitemlatestRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'duration_in_millis')
    self.duration_in_millis = attributes[:'duration_in_millis']
  end

  if attributes.key?(:'estimated_duration_in_millis')
    self.estimated_duration_in_millis = attributes[:'estimated_duration_in_millis']
  end

  if attributes.key?(:'en_queue_time')
    self.en_queue_time = attributes[:'en_queue_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'pipeline')
    self.pipeline = attributes[:'pipeline']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'run_summary')
    self.run_summary = attributes[:'run_summary']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'commit_id')
    self.commit_id = attributes[:'commit_id']
  end

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end
end

Instance Attribute Details

#_classObject

Returns the value of attribute _class.



44
45
46
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 44

def _class
  @_class
end

#commit_idObject

Returns the value of attribute commit_id.



42
43
44
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 42

def commit_id
  @commit_id
end

#duration_in_millisObject

Returns the value of attribute duration_in_millis.



18
19
20
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 18

def duration_in_millis
  @duration_in_millis
end

#en_queue_timeObject

Returns the value of attribute en_queue_time.



22
23
24
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 22

def en_queue_time
  @en_queue_time
end

#end_timeObject

Returns the value of attribute end_time.



24
25
26
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 24

def end_time
  @end_time
end

#estimated_duration_in_millisObject

Returns the value of attribute estimated_duration_in_millis.



20
21
22
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 20

def estimated_duration_in_millis
  @estimated_duration_in_millis
end

#idObject

Returns the value of attribute id.



26
27
28
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 26

def id
  @id
end

#organizationObject

Returns the value of attribute organization.



28
29
30
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 28

def organization
  @organization
end

#pipelineObject

Returns the value of attribute pipeline.



30
31
32
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 30

def pipeline
  @pipeline
end

#resultObject

Returns the value of attribute result.



32
33
34
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 32

def result
  @result
end

#run_summaryObject

Returns the value of attribute run_summary.



34
35
36
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 34

def run_summary
  @run_summary
end

#start_timeObject

Returns the value of attribute start_time.



36
37
38
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 36

def start_time
  @start_time
end

#stateObject

Returns the value of attribute state.



38
39
40
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 38

def state
  @state
end

#typeObject

Returns the value of attribute type.



40
41
42
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 40

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 47

def self.attribute_map
  {
    :'duration_in_millis' => :'durationInMillis',
    :'estimated_duration_in_millis' => :'estimatedDurationInMillis',
    :'en_queue_time' => :'enQueueTime',
    :'end_time' => :'endTime',
    :'id' => :'id',
    :'organization' => :'organization',
    :'pipeline' => :'pipeline',
    :'result' => :'result',
    :'run_summary' => :'runSummary',
    :'start_time' => :'startTime',
    :'state' => :'state',
    :'type' => :'type',
    :'commit_id' => :'commitId',
    :'_class' => :'_class'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 77

def self.openapi_types
  {
    :'duration_in_millis' => :'Integer',
    :'estimated_duration_in_millis' => :'Integer',
    :'en_queue_time' => :'String',
    :'end_time' => :'String',
    :'id' => :'String',
    :'organization' => :'String',
    :'pipeline' => :'String',
    :'result' => :'String',
    :'run_summary' => :'String',
    :'start_time' => :'String',
    :'state' => :'String',
    :'type' => :'String',
    :'commit_id' => :'String',
    :'_class' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      duration_in_millis == o.duration_in_millis &&
      estimated_duration_in_millis == o.estimated_duration_in_millis &&
      en_queue_time == o.en_queue_time &&
      end_time == o.end_time &&
      id == o.id &&
      organization == o.organization &&
      pipeline == o.pipeline &&
      result == o.result &&
      run_summary == o.run_summary &&
      start_time == o.start_time &&
      state == o.state &&
      type == o.type &&
      commit_id == o.commit_id &&
      _class == o._class
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 219

def hash
  [duration_in_millis, estimated_duration_in_millis, en_queue_time, end_time, id, organization, pipeline, result, run_summary, start_time, state, type, commit_id, _class].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
# File 'lib/swaggy_jenkins/models/pipeline_branchesitemlatest_run.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end