Class: SwaggyJenkinsClient::PipelinelatestRun
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SwaggyJenkinsClient::PipelinelatestRun
- Defined in:
- lib/swaggy_jenkins/models/pipelinelatest_run.rb
Instance Attribute Summary collapse
-
#_class ⇒ Object
Returns the value of attribute _class.
-
#artifacts ⇒ Object
Returns the value of attribute artifacts.
-
#commit_id ⇒ Object
Returns the value of attribute commit_id.
-
#duration_in_millis ⇒ Object
Returns the value of attribute duration_in_millis.
-
#en_queue_time ⇒ Object
Returns the value of attribute en_queue_time.
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#estimated_duration_in_millis ⇒ Object
Returns the value of attribute estimated_duration_in_millis.
-
#id ⇒ Object
Returns the value of attribute id.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#pipeline ⇒ Object
Returns the value of attribute pipeline.
-
#result ⇒ Object
Returns the value of attribute result.
-
#run_summary ⇒ Object
Returns the value of attribute run_summary.
-
#start_time ⇒ Object
Returns the value of attribute start_time.
-
#state ⇒ Object
Returns the value of attribute state.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PipelinelatestRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PipelinelatestRun
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggyJenkinsClient::PipelinelatestRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggyJenkinsClient::PipelinelatestRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'artifacts') if (value = attributes[:'artifacts']).is_a?(Array) self.artifacts = value end end if attributes.key?(:'duration_in_millis') self.duration_in_millis = attributes[:'duration_in_millis'] end if attributes.key?(:'estimated_duration_in_millis') self.estimated_duration_in_millis = attributes[:'estimated_duration_in_millis'] end if attributes.key?(:'en_queue_time') self.en_queue_time = attributes[:'en_queue_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'pipeline') self.pipeline = attributes[:'pipeline'] end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'run_summary') self.run_summary = attributes[:'run_summary'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'commit_id') self.commit_id = attributes[:'commit_id'] end if attributes.key?(:'_class') self._class = attributes[:'_class'] end end |
Instance Attribute Details
#_class ⇒ Object
Returns the value of attribute _class.
46 47 48 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 46 def _class @_class end |
#artifacts ⇒ Object
Returns the value of attribute artifacts.
18 19 20 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 18 def artifacts @artifacts end |
#commit_id ⇒ Object
Returns the value of attribute commit_id.
44 45 46 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 44 def commit_id @commit_id end |
#duration_in_millis ⇒ Object
Returns the value of attribute duration_in_millis.
20 21 22 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 20 def duration_in_millis @duration_in_millis end |
#en_queue_time ⇒ Object
Returns the value of attribute en_queue_time.
24 25 26 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 24 def en_queue_time @en_queue_time end |
#end_time ⇒ Object
Returns the value of attribute end_time.
26 27 28 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 26 def end_time @end_time end |
#estimated_duration_in_millis ⇒ Object
Returns the value of attribute estimated_duration_in_millis.
22 23 24 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 22 def estimated_duration_in_millis @estimated_duration_in_millis end |
#id ⇒ Object
Returns the value of attribute id.
28 29 30 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 28 def id @id end |
#organization ⇒ Object
Returns the value of attribute organization.
30 31 32 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 30 def organization @organization end |
#pipeline ⇒ Object
Returns the value of attribute pipeline.
32 33 34 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 32 def pipeline @pipeline end |
#result ⇒ Object
Returns the value of attribute result.
34 35 36 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 34 def result @result end |
#run_summary ⇒ Object
Returns the value of attribute run_summary.
36 37 38 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 36 def run_summary @run_summary end |
#start_time ⇒ Object
Returns the value of attribute start_time.
38 39 40 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 38 def start_time @start_time end |
#state ⇒ Object
Returns the value of attribute state.
40 41 42 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 40 def state @state end |
#type ⇒ Object
Returns the value of attribute type.
42 43 44 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 42 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 49 def self.attribute_map { :'artifacts' => :'artifacts', :'duration_in_millis' => :'durationInMillis', :'estimated_duration_in_millis' => :'estimatedDurationInMillis', :'en_queue_time' => :'enQueueTime', :'end_time' => :'endTime', :'id' => :'id', :'organization' => :'organization', :'pipeline' => :'pipeline', :'result' => :'result', :'run_summary' => :'runSummary', :'start_time' => :'startTime', :'state' => :'state', :'type' => :'type', :'commit_id' => :'commitId', :'_class' => :'_class' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 237 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 80 def self.openapi_types { :'artifacts' => :'Array<PipelinelatestRunartifacts>', :'duration_in_millis' => :'Integer', :'estimated_duration_in_millis' => :'Integer', :'en_queue_time' => :'String', :'end_time' => :'String', :'id' => :'String', :'organization' => :'String', :'pipeline' => :'String', :'result' => :'String', :'run_summary' => :'String', :'start_time' => :'String', :'state' => :'String', :'type' => :'String', :'commit_id' => :'String', :'_class' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && artifacts == o.artifacts && duration_in_millis == o.duration_in_millis && estimated_duration_in_millis == o.estimated_duration_in_millis && en_queue_time == o.en_queue_time && end_time == o.end_time && id == o.id && organization == o.organization && pipeline == o.pipeline && result == o.result && run_summary == o.run_summary && start_time == o.start_time && state == o.state && type == o.type && commit_id == o.commit_id && _class == o._class end |
#eql?(o) ⇒ Boolean
224 225 226 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 224 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
230 231 232 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 230 def hash [artifacts, duration_in_millis, estimated_duration_in_millis, en_queue_time, end_time, id, organization, pipeline, result, run_summary, start_time, state, type, commit_id, _class].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 187 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 |
# File 'lib/swaggy_jenkins/models/pipelinelatest_run.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |